==> cspace-input-0.12.51.tgz: package/src/components/SubstringFilteringDropdownMenuInput.jsx <==
import React, { Component } from 'react';
import FilteringDropdownMenuInput from './FilteringDropdownMenuInput';
import { filterOptionsBySubstring } from '../helpers/optionHelpers';

const propTypes = FilteringDropdownMenuInput.propTypes;

export default class SubstringFilteringDropdownMenuInput extends Component {
  constructor(props) {
    super(props);

    this.filter = this.filter.bind(this);
    this.handleDropdownInputCommit = this.handleDropdownInputCommit.bind(this);

    const substring = null;

    this.state = {
      substring,
      filteredOptions: filterOptionsBySubstring(props.options, substring),
      value: props.value,
    };
  }

  componentWillReceiveProps(nextProps) {
    this.setState({
      filteredOptions: filterOptionsBySubstring(nextProps.options, this.state.substring),
      value: nextProps.value,
    });
  }

  filter(substring) {
    this.setState({
      substring,
      filteredOptions: filterOptionsBySubstring(this.props.options, substring),
    });
  }

  handleDropdownInputCommit(path, value) {
    const substring = null;

    this.setState({
      substring,
      value,
      filteredOptions: filterOptionsBySubstring(this.props.options, substring),
    });

    const {
      onCommit,
    } = this.props;

    if (onCommit) {
      onCommit(path, value);
    }
  }

  render() {
    const {
      /* eslint-disable no-unused-vars */
      options,
      /* eslint-enable no-unused-vars */
      ...remainingProps
    } = this.props;

    const {
      filteredOptions,
      value,
    } = this.state;

    return (
      <FilteringDropdownMenuInput
        {...remainingProps}
        filter={this.filter}
        options={filteredOptions}
        value={value}
        onCommit={this.handleDropdownInputCommit}
      />
    );
  }
}

SubstringFilteringDropdownMenuInput.propTypes = propTypes;

==> cspace-input-1.4.2.tgz: package/src/components/SubstringFilteringDropdownMenuInput.jsx <==
import React, { Component } from 'react';
import FilteringDropdownMenuInput from './FilteringDropdownMenuInput';
import { filterOptionsBySubstring } from '../helpers/optionHelpers';

// TODO: Stop using propTypes in isInput, and in render method of cspace-ui Field component.
// Until then, propTypes need to be hoisted from the base component.
// eslint-disable-next-line react/forbid-foreign-prop-types
const { propTypes } = FilteringDropdownMenuInput;

export default class SubstringFilteringDropdownMenuInput extends Component {
  constructor(props) {
    super(props);

    this.filter = this.filter.bind(this);
    this.handleDropdownInputCommit = this.handleDropdownInputCommit.bind(this);

    const substring = null;

    this.state = {
      substring,
      filteredOptions: filterOptionsBySubstring(props.options, substring),
      value: props.value,
    };
  }

  componentWillReceiveProps(nextProps) {
    const {
      options,
      value,
    } = nextProps;

    this.setState((prevState) => ({
      value,
      filteredOptions: filterOptionsBySubstring(options, prevState.substring),
    }));
  }

  filter(substring) {
    const {
      options,
    } = this.props;

    this.setState({
      substring,
      filteredOptions: filterOptionsBySubstring(options, substring),
    });
  }

  handleDropdownInputCommit(path, value) {
    const {
      options,
      onCommit,
    } = this.props;

    const substring = null;

    this.setState({
      substring,
      value,
      filteredOptions: filterOptionsBySubstring(options, substring),
    });

    if (onCommit) {
      onCommit(path, value);
    }
  }

  render() {
    const {
      options,
      ...remainingProps
    } = this.props;

    const {
      filteredOptions,
      value,
    } = this.state;

    return (
      <FilteringDropdownMenuInput
        // eslint-disable-next-line react/jsx-props-no-spreading
        {...remainingProps}
        filter={this.filter}
        options={filteredOptions}
        value={value}
        onCommit={this.handleDropdownInputCommit}
      />
    );
  }
}

SubstringFilteringDropdownMenuInput.propTypes = propTypes;
